@@ -662,6 +662,8 @@ static const char *ui_description =
 		G_CALLBACK (on_callentry_insert_text), NULL);
 	g_signal_connect ((gpointer) callentry, "changed",
 		G_CALLBACK (on_callentry_changed), NULL);
+	g_signal_connect ((gpointer) callentry, "focus-out-event",
+		G_CALLBACK (on_callentry_unfocus), NULL);
 	g_signal_connect ((gpointer) callbutton, "clicked",
 		G_CALLBACK (on_callbutton_clicked), NULL);
 	g_signal_connect ((gpointer) locatorentry, "changed",
